@@ -4,14 +4,13 @@ from tests import DeclarativeTestCase, ClassicTestCase
 
 
 class Suite(object):
-    def test_as_object_property_with_force_locale(self):
+    def test_as_object_property(self):
         article = self.Article()
         article.name = u'Some article'
         article.content = u'Some content'
         self.session.add(article)
         self.session.commit()
-        with article.force_locale('fi'):
-            assert article.current_translation == article._translation_fi
+        assert article.current_translation.name == u'Some article'
 
     def test_as_class_property(self):
         assert self.Article.current_translation
